summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcombobox_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcombobox_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcombobox_imp.cpp120
1 files changed, 60 insertions, 60 deletions
diff --git a/kjsembed/qtbindings/qcombobox_imp.cpp b/kjsembed/qtbindings/qcombobox_imp.cpp
index 56407cb7..330da994 100644
--- a/kjsembed/qtbindings/qcombobox_imp.cpp
+++ b/kjsembed/qtbindings/qcombobox_imp.cpp
@@ -1,10 +1,10 @@
-#include <qcstring.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -13,7 +13,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcombobox.h>
+#include <tqcombobox.h>
#include "qcombobox_imp.h"
/**
@@ -41,7 +41,7 @@ void QComboBoxImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -64,12 +64,12 @@ void QComboBoxImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
EnumValue enums[] = {
// enum Policy
- { "NoInsertion", QComboBox::NoInsertion },
- { "AtTop", QComboBox::AtTop },
- { "AtCurrent", QComboBox::AtCurrent },
- { "AtBottom", QComboBox::AtBottom },
- { "AfterCurrent", QComboBox::AfterCurrent },
- { "BeforeCurrent", QComboBox::BeforeCurrent },
+ { "NoInsertion", TQComboBox::NoInsertion },
+ { "AtTop", TQComboBox::AtTop },
+ { "AtCurrent", TQComboBox::AtCurrent },
+ { "AtBottom", TQComboBox::AtBottom },
+ { "AfterCurrent", TQComboBox::AfterCurrent },
+ { "BeforeCurrent", TQComboBox::BeforeCurrent },
{ 0, 0 }
};
@@ -137,7 +137,7 @@ void QComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -150,25 +150,25 @@ void QComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QComboBox pointer from an Object.
*/
-QComboBox *QComboBoxImp::toQComboBox( KJS::Object &self )
+TQComboBox *QComboBoxImp::toQComboBox( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QComboBox *>( obj );
+ return dynamic_cast<TQComboBox *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QComboBox" )
+ if ( op->typeName() != "TQComboBox" )
return 0;
- return op->toNative<QComboBox>();
+ return op->toNative<TQComboBox>();
}
/**
@@ -190,7 +190,7 @@ KJS::Object QComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &args
break;
}
- QString msg = i18n("QComboBoxCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QComboBoxCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -198,15 +198,15 @@ KJS::Object QComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &args
KJS::Object QComboBoxImp::QComboBox_1( KJS::ExecState *exec, const KJS::List &args )
{
#if 0
// Unsupported parameter QWidget *
return KJS::Value();
- QWidget * arg0; // Dummy
+ TQWidget * arg0; // Dummy
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
// We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
arg0,
arg1 );
@@ -219,15 +219,15 @@ KJS::Object QComboBoxImp::QComboBox_2( KJS::ExecState *exec, const KJS::List &ar
#if 0
bool arg0 = extractBool(exec, args, 0);
// Unsupported parameter QWidget *
return KJS::Value();
- QWidget * arg1; // Dummy
+ TQWidget * arg1; // Dummy
const char *arg2 = (args.size() >= 3) ? args[2].toString(exec).ascii() : 0;
// We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
arg0,
arg1,
@@ -427,7 +427,7 @@ KJS::Value QComboBoxImp::call( KJS::ExecState *exec, KJS::Object &self, const KJ
break;
}
- QString msg = i18n( "QComboBoxImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QComboBoxImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -444,7 +444,7 @@ KJS::Value QComboBoxImp::count_4( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value QComboBoxImp::insertStringList_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QStringList arg0 = extractQStringList(exec, args, 0);
+ TQStringList arg0 = extractQStringList(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -458,7 +458,7 @@ KJS::Value QComboBoxImp::insertStringList_5( KJS::ExecState *exec, KJS::Object &
KJS::Value QComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QStrList arg0 = extractQStrList(exec, args, 0);
+ TQStrList arg0 = extractQStrList(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -472,10 +472,10 @@ KJS::Value QComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &obj
KJS::Value QComboBoxImp::insertStrList_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QStrList *
return KJS::Value();
- const QStrList * arg0; // Dummy
+ const TQStrList * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -509,7 +509,7 @@ KJS::Value QComboBoxImp::insertStrList_8( KJS::ExecState *exec, KJS::Object &obj
KJS::Value QComboBoxImp::insertItem_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -523,7 +523,7 @@ KJS::Value QComboBoxImp::insertItem_9( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QComboBoxImp::insertItem_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPixmap arg0 = extractQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractQPixmap(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -537,9 +537,9 @@ KJS::Value QComboBoxImp::insertItem_10( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QComboBoxImp::insertItem_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPixmap arg0 = extractQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractQPixmap(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
+ TQString arg1 = extractQString(exec, args, 1);
int arg2 = extractInt(exec, args, 2);
@@ -585,7 +585,7 @@ KJS::Value QComboBoxImp::setCurrentItem_14( KJS::ExecState *exec, KJS::Object &o
KJS::Value QComboBoxImp::currentText_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString ret;
+ TQString ret;
ret = instance->currentText( );
return KJS::String( ret );
@@ -594,7 +594,7 @@ KJS::Value QComboBoxImp::currentText_15( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QComboBoxImp::setCurrentText_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
instance->setCurrentText(
arg0 );
@@ -607,7 +607,7 @@ KJS::Value QComboBoxImp::text_17( KJS::ExecState *exec, KJS::Object &obj, const
int arg0 = extractInt(exec, args, 0);
- QString ret;
+ TQString ret;
ret = instance->text(
arg0 );
return KJS::String( ret );
@@ -621,14 +621,14 @@ KJS::Value QComboBoxImp::pixmap_18( KJS::ExecState *exec, KJS::Object &obj, cons
instance->pixmap(
arg0 );
- return KJS::Value(); // Returns 'const QPixmap *'
+ return KJS::Value(); // Returns 'const TQPixmap *'
}
KJS::Value QComboBoxImp::changeItem_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -642,7 +642,7 @@ KJS::Value QComboBoxImp::changeItem_19( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QComboBoxImp::changeItem_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPixmap arg0 = extractQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractQPixmap(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -656,9 +656,9 @@ KJS::Value QComboBoxImp::changeItem_20( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QComboBoxImp::changeItem_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPixmap arg0 = extractQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractQPixmap(exec, args, 0);
- QString arg1 = extractQString(exec, args, 1);
+ TQString arg1 = extractQString(exec, args, 1);
int arg2 = extractInt(exec, args, 2);
@@ -692,7 +692,7 @@ KJS::Value QComboBoxImp::setAutoResize_23( KJS::ExecState *exec, KJS::Object &ob
KJS::Value QComboBoxImp::sizeHint_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QSize ret;
+ TQSize ret;
ret = instance->sizeHint( );
return convertToValue( exec, ret );
@@ -702,7 +702,7 @@ KJS::Value QComboBoxImp::sizeHint_24( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QComboBoxImp::setPalette_25( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPalette arg0 = extractQPalette(exec, args, 0);
+ TQPalette arg0 = extractQPalette(exec, args, 0);
instance->setPalette(
arg0 );
@@ -713,7 +713,7 @@ KJS::Value QComboBoxImp::setPalette_25( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QComboBoxImp::setFont_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QFont arg0 = extractQFont(exec, args, 0);
+ TQFont arg0 = extractQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -775,7 +775,7 @@ KJS::Value QComboBoxImp::maxCount_31( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QComboBoxImp::setInsertionPolicy_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QComboBox::Policy arg0 = QComboBox::AtBottom; // TODO (hack for combo box)
+ TQComboBox::Policy arg0 = TQComboBox::AtBottom; // TODO (hack for combo box)
instance->setInsertionPolicy(
arg0 );
@@ -794,10 +794,10 @@ KJS::Value QComboBoxImp::insertionPolicy_33( KJS::ExecState *exec, KJS::Object &
KJS::Value QComboBoxImp::setValidator_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QValidator *
return KJS::Value();
- const QValidator * arg0; // Dummy
+ const TQValidator * arg0; // Dummy
instance->setValidator(
arg0 );
@@ -809,17 +809,17 @@ KJS::Value QComboBoxImp::validator_35( KJS::ExecState *exec, KJS::Object &obj, c
{
instance->validator( );
- return KJS::Value(); // Returns 'const QValidator *'
+ return KJS::Value(); // Returns 'const TQValidator *'
}
KJS::Value QComboBoxImp::setListBox_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter QListBox *
return KJS::Value();
- QListBox * arg0; // Dummy
+ TQListBox * arg0; // Dummy
instance->setListBox(
arg0 );
@@ -831,17 +831,17 @@ KJS::Value QComboBoxImp::listBox_37( KJS::ExecState *exec, KJS::Object &obj, con
{
instance->listBox( );
- return KJS::Value(); // Returns 'QListBox *'
+ return KJS::Value(); // Returns 'TQListBox *'
}
KJS::Value QComboBoxImp::setLineEdit_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter QLineEdit *
return KJS::Value();
- QLineEdit * arg0; // Dummy
+ TQLineEdit * arg0; // Dummy
instance->setLineEdit(
arg0 );
@@ -853,7 +853,7 @@ KJS::Value QComboBoxImp::lineEdit_39( KJS::ExecState *exec, KJS::Object &obj, co
{
instance->lineEdit( );
- return KJS::Value(); // Returns 'QLineEdit *'
+ return KJS::Value(); // Returns 'TQLineEdit *'
}
@@ -880,15 +880,15 @@ KJS::Value QComboBoxImp::autoCompletion_41( KJS::ExecState *exec, KJS::Object &o
KJS::Value QComboBoxImp::eventFilter_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter QObject *
return KJS::Value();
- QObject * arg0; // Dummy
+ TQObject * arg0; // Dummy
- // Unsupported parameter QEvent *
+ // Unsupported parameter TQEvent *
return KJS::Value();
- QEvent * arg1; // Dummy
+ TQEvent * arg1; // Dummy
bool ret;
ret = instance->eventFilter(
@@ -150,25 +150,25 @@ void QComboBoxImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QComboBox pointer from an Object.
+ * Extract a TQComboBox pointer from an Object.
*/
@@ -198,15 +198,15 @@ KJS::Object QComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &args
{
#if 0
- // Unsupported parameter QWidget *
+ // Unsupported parameter TQWidget *
return KJS::Value();
@@ -198,15 +198,15 @@ KJS::Object QComboBoxImp::construct( KJS::ExecState *exec, const KJS::List &args
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
- // We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
+ // We should now create an object of type QComboBoxQComboBox *ret = new TQComboBox(
arg0,
arg1 );
@@ -219,15 +219,15 @@ KJS::Object QComboBoxImp::QComboBox_2( KJS::ExecState *exec, const KJS::List &ar
#if 0
bool arg0 = extractBool(exec, args, 0);
- // Unsupported parameter QWidget *
+ // Unsupported parameter TQWidget *
return KJS::Value();
@@ -219,15 +219,15 @@ KJS::Object QComboBoxImp::QComboBox_2( KJS::ExecState *exec, const KJS::List &ar
const char *arg2 = (args.size() >= 3) ? args[2].toString(exec).ascii() : 0;
- // We should now create an object of type QComboBoxQComboBox *ret = new QComboBox(
+ // We should now create an object of type QComboBoxQComboBox *ret = new TQComboBox(
arg0,
arg1,
@@ -472,10 +472,10 @@ KJS::Value QComboBoxImp::insertStrList_6( KJS::ExecState *exec, KJS::Object &obj
KJS::Value QComboBoxImp::insertStrList_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QStrList *
+ // Unsupported parameter const TQStrList *
return KJS::Value();
@@ -794,10 +794,10 @@ KJS::Value QComboBoxImp::insertionPolicy_33( KJS::ExecState *exec, KJS::Object &
KJS::Value QComboBoxImp::setValidator_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QValidator *
+ // Unsupported parameter const TQValidator *
return KJS::Value();
@@ -809,17 +809,17 @@ KJS::Value QComboBoxImp::validator_35( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value QComboBoxImp::setListBox_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QListBox *
+ // Unsupported parameter TQListBox *
return KJS::Value();
@@ -831,17 +831,17 @@ KJS::Value QComboBoxImp::listBox_37( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value QComboBoxImp::setLineEdit_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QLineEdit *
+ // Unsupported parameter TQLineEdit *
return KJS::Value();
@@ -880,15 +880,15 @@ KJS::Value QComboBoxImp::autoCompletion_41( KJS::ExecState *exec, KJS::Object &o
KJS::Value QComboBoxImp::eventFilter_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QObject *
+ // Unsupported parameter TQObject *
return KJS::Value();